@@ -762,5 +762,21 @@ sub SelectDeps {
 	}
 }
 
+####################################################################
+# $Netpkg->AsyncRun( $command );
+sub AsyncRun {
+	my $self = shift; 
+	my $command = shift;
+	    
+    # initialize the shared semaphor to '0', then wait for the thread to set it to '1'
+    $semaphorus = 0;
+	my $thr = threads->new(\&Execute, $command);
+	while ($semaphorus == 0) {
+		Gtk2->main_iteration while ( Gtk2->events_pending  );  
+	}
+	return 0;
+}
+
+
 1;
 
